.. _chapter_examples:

========
Examples
========

This chapter offers a list of examples illustrating how RADICAL-Analytics can
be used to perform duration and concurrency analysis of a RADICAL-Cybertool
dataset. Currently, all the examples use a dataset produced by `RADICAL-Pilot <https://github.com/radical-cybertools/radical.pilot>`_. The reader should
note that the calls and analyses illustrated apply to RADICAL-Cybertools in
general.

.. toctree::
   :maxdepth: 2

   session_construction
   00_session_describe_rp
   01_session_list_rp
   02_session_get_rp
   03_session_filter_rp
   04_session_duration_rp
